==> img0ch-2.1.21.tar.bz2: img0ch/_template/type/read.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:html_escape(BBS_TITLE) ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/cookie.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//]]>
</script>
<style type="text/css">
@charset "shift_jis";
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
.right { text-align: right !important; }
.res_body {
  font-size: 12pt;
  font-family: "Mona","IPA i[ PSVbN","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS P޼","MS PSVbN",sans-serif;
  line-height: 115% !important;
}
</style>
<?cs var:META ?>
</head>
<body>

<h1><?cs var:Subject ?></h1>

<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject"><?cs var:Subject ?></span>
 </h2>

 <div class="form">
  <div class="caption">
   <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂遡</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/1-100">1-</a>
   <?cs each:item = LinkStack ?>
    <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(item.start) ?>-<?cs var:html_escape(item.end) ?>">
     <?cs var:html_escape(item.start) ?>-
    </a>
   <?cs /each ?>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
   <?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if  ?>
  </div>
  <div class="section">
   <p>
   ݕ\ĂXbhdat̑傫<strong><?cs var:html_escape(DatKByteSize) ?></strong>KBłB<br />
   <?cs if:R100 ?>
    X1000𒴂Ă܂BcOȂS͕\܂B
   <?cs elif:R95 ?>
    X950𒴂Ă܂B1000𒴂ƕ\łȂȂ܂B
   <?cs elif:R90 ?>
    X900𒴂Ă܂B1000𒴂ƕ\łȂȂ܂B
   <?cs /if ?>
   </p>
  </div>
 </div>

 <div class="body thread_body" id="t_<?cs var:html_escape(KEY) ?>">
  <?cs each:res = Thread ?>
   <div class="section" id="r_<?cs var:html_escape(res.resno) ?>">
    <div class="caption res_header">
     <?cs var:html_escape(res.resno) ?>
     OF<span class="commentator">
     <?cs if:res.mail ?>
      <a href="mailto:<?cs var:html_escape(res.mail) ?>" rel="nofollow"><b><?cs var:res.name ?></b></a>
     <?cs else ?>
      <span class="nomail"><b><?cs var:res.name ?></b></span>
     <?cs /if ?>
     </span>:<span class="commenttime"><?cs var:html_escape(res.date) ?></span>
    </div>
    <p class="res_body"><?cs var:res.text ?></p>
   </div>
  <?cs /each ?>
 </div>
 <?cs if:!R100 ?>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
    <input type="hidden" name="key" value="<?cs var:html_escape(key) ?>" />
    <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>" />
   </div>
   <div>
    <div class="field name">
     OF<input type="text" name="FROM" value="" size="19" />
    </div>
    <div class="field mail">
     [F<input type="text" name="mail" value="" size="19" />
    </div>
   </div>
   <?cs if:UploadableFromRes ?>
   <div>
    <div class="field name">
     摜F<input type="file" name="file" />
    </div>
    <div class="field mail">
     폜pXF<input type="password" name="pass" />
    </div>
   </div>
   <?cs /if ?>
   <?cs if:Icon ?>
   <div class="textarea">
    ACRF<select name="icon"><option value="" selected="selected">Ȃ</option>
    <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
    <?cs /each ?></select>
   </div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="" />
   </div>
  </form>
 </div>
 <?cs /if ?>
 <div class="referer">
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(ResCount) ?>-n">VX̕\</a>
  <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(PrevStart) ?>-<?cs var:html_escape(PrevEnd) ?>">O100</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(NextStart) ?>-<?cs var:html_escape(NextEnd) ?>">100</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
  <?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(key) ?>/">t@CǗ</a><?cs /if  ?>
 </div>
</div>

<div class="footer">
 <a href="http://img0ch.sourceforge.jp"><?cs var:html_escape(VERSION) ?></a>
</div>

</body>
</html>

==> img0ch-3.1.3.tar.bz2: img0ch/_template/type/read.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?cs var:html_escape(Subject) ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
app.initForm("<?cs var:html_escape(BBS_COOKIE_PATH) ?>");
//]]>
</script>
<style type="text/css">
@charset "shift_jis";
fieldset { border: 0px; }
img { border: 0px; }
.center { text-align:center !important;  }
.clear { clear: both !important; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; margin-right: 4px; margin-bottom: 1px; }
.right { text-align: right !important; }
.res_body {
  font-size: 12pt;
  font-family: "Mona","IPA i[ PSVbN","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS P޼","MS PSVbN",sans-serif;
  line-height: 115% !important;
}
</style>
<?cs var:META ?>
</head>
<body>

<h1><?cs var:html_escape(Subject) ?></h1>

<?cs if:Banner ?>
<hr class="sep" />
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject"><?cs var:html_escape(Subject) ?></span>
 </h2>

 <div class="form">
  <div class="caption">
   <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂遡</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/1-100">1-</a>
   <?cs each:item = LinkStack ?>
    <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(item.start) ?>-<?cs var:html_escape(item.end) ?>">
     <?cs var:html_escape(item.start) ?>-
    </a>
   <?cs /each ?>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
   <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50" onclick="app.enableRedirectRenderer();app.redirectRenderer(this)">read.htmlɐ؂ւ</a>
   <?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/">t@CǗ</a><?cs /if  ?>
  </div>
  <div class="section">
   <p>
   ݕ\ĂXbhdat̑傫<strong><?cs var:html_escape(DatKByteSize) ?></strong>KBłB<br />
   <?cs if:R100 ?>
    X<?cs var:html_escape(BBS_RES_MAX) ?>𒴂Ă܂BcOȂS͕\܂B
   <?cs elif:R95 ?>
    X<?cs var:html_escape(R95C) ?>𒴂Ă܂B<?cs var:html_escape(BBS_RES_MAX) ?>𒴂ƕ\łȂȂ܂B
   <?cs elif:R90 ?>
    X<?cs var:html_escape(R90C) ?>𒴂Ă܂B<?cs var:html_escape(BBS_RES_MAX) ?>𒴂ƕ\łȂȂ܂B
   <?cs /if ?>
   </p>
  </div>
 </div>

 <div class="body thread_body" id="t_<?cs var:html_escape(KEY) ?>">
  <?cs each:res = Thread ?>
   <div class="section" id="r_<?cs var:html_escape(res.resno) ?>">
    <div class="caption res_header">
     <?cs var:html_escape(res.resno) ?>
     OF<span class="commentator">
     <?cs if:res.mail ?>
      <a href="mailto:<?cs var:html_escape(res.mail) ?>" rel="nofollow"><b><?cs var:res.name ?></b></a>
     <?cs else ?>
      <span class="nomail"><b><?cs var:res.name ?></b></span>
     <?cs /if ?>
     </span>:<span class="commenttime"><?cs var:res.date ?></span>
    </div>
    <p class="res_body"><?cs var:res.text ?></p>
   </div>
  <?cs /each ?>
 </div>
 <?cs if:!R100 ?>
 <div class="form">
  <form class="comment" method="post" action="<?cs var:html_escape(CGIURI) ?>/bbs.cgi?guid=on" enctype="multipart/form-data">
   <div class="hidden_field">
    <input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" />
    <input type="hidden" name="key" value="<?cs var:html_escape(key) ?>" />
    <input type="hidden" name="time" value="<?cs var:html_escape(TimeStamp) ?>" />
   </div>
   <div>
    <div class="field name">
     OF<input type="text" name="FROM" value="" size="19" />
    </div>
    <div class="field mail">
     [F<input type="text" name="mail" value="" size="19" />
    </div>
   </div>
   <?cs if:UploadableFromRes ?>
   <div>
    <div class="field name">
     摜F<input type="file" name="file" />
    </div>
    <div class="field mail">
     폜pXF<input type="password" name="pass" />
    </div>
   </div>
   <?cs /if ?>
   <?cs if:Icon ?>
   <div class="textarea">
    ACRF<select name="icon"><option value="" selected="selected">Ȃ</option>
    <?cs each:item = Icons ?><option value="<?cs var:item.id ?>"><?cs var:item.name ?></option>
    <?cs /each ?></select>
   </div>
   <?cs /if ?>
   <div class="textarea">
    RgF<textarea rows="5" cols="64" name="MESSAGE"></textarea>
   </div>
   <div class="button">
    <input type="submit" name="submit" value="" />
   </div>
  </form>
 </div>
 <?cs /if ?>
 <div class="referer">
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(ResCount) ?>-n">VX̕\</a>
  <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/">S</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(PrevStart) ?>-<?cs var:html_escape(PrevEnd) ?>">O100</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/<?cs var:html_escape(NextStart) ?>-<?cs var:html_escape(NextEnd) ?>">100</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50">ŐV50</a>
  <a href="<?cs var:html_escape(ReadCGIURI) ?>/l50" onclick="app.enableRedirectRenderer();app.redirectRenderer(this)">read.htmlɐ؂ւ</a>
  <?cs if:Uploadable ?><a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(key) ?>/">t@CǗ</a><?cs /if  ?>
 </div>
</div>

<div class="footer">
 <a href="http://img0ch.sourceforge.jp"><?cs var:html_escape(VERSION) ?></a>
</div>

</body>
</html>
